@@ -2,14 +2,13 @@
 
 use strict;
 use warnings;
-use v5.10;
 use AnyEvent::Finger::Server;
 
 # bind to 79 if root, otherwise use
 # an unprivilaged port
 my $port = ($> && $^O !~ /^(cygwin|MSWin32)$/) ? 8079 : 79;
 
-say "listening to port $port";
+print "listening to port $port\n";
 
 my $server = AnyEvent::Finger::Server->new( port => $port );
 
